@@ -1,3 +1,3 @@
-from .bib import IzBib, NzBib
+from .bib import IzBib, NzBib, fetch_nz_bibs
 from .holding import Holding
 from .item import Item
