@@ -2,7 +2,6 @@
 import os
 from typing import Optional, ClassVar, Literal
 import logging
-import requests
 from ..record import Record, check_error, XmlData
 import almapiwrapper.inventory as inventory
 from lxml import etree
@@ -49,11 +48,17 @@ class Item(Record):
         """Construct an item.
         """
         self.error = False
+        self.error_msg = None
         self._data = data
+
+        if holding_id is not None and mms_id is not None and holding is None:
+            holding = inventory.Holding(mms_id, holding_id, zone, env)
+
         self.holding = holding
         self.item_id = item_id
         self._barcode = barcode
         self.area = 'Bibs'
+        self.format = 'xml'
 
         # Set 'env' and 'zone' either from holding data either from parameters
         if holding is not None:
@@ -63,15 +68,10 @@ class Item(Record):
             self.zone = zone
             self.env = env
 
-        # Create a new item if 'create_item' parameter is True and holding provided
+        # Create a new item if 'create_item' parameter is True
         if self.item_id is None and data is not None and holding is not None and create_item is True:
             self._create_item(data)
 
-        # Create a new item if 'create_item' parameter is True and holding_id and mms_id provided
-        if self.item_id is None and data is not None and holding_id is not None \
-                and mms_id is not None and create_item is True:
-            self._create_item(data, mms_id=mms_id, holding_id=holding_id)
-
         # Fetch the item from the barcode, zone and env must be available
         elif barcode is not None and create_item is False and data is None:
             data = self._fetch_data(barcode)
@@ -101,7 +101,7 @@ class Item(Record):
         :return: string
         """
         if self._holding is None and self._barcode is not None:
-            return f"{self.__class__.__name__}(barcode='{self._barcode}' " \
+            return f"{self.__class__.__name__}(barcode='{self._barcode}', " \
                    f"zone='{self.zone}', env='{self.env}')"
         return f"{self.__class__.__name__}('{self.bib.mms_id}', '{self.holding.holding_id}'," \
                f"'{self.item_id}', '{self.zone}', '{self.env}')"
@@ -114,9 +114,10 @@ class Item(Record):
         :return: None
         """
         if barcode is not None:
-            r = requests.get(self.api_base_url_items,
-                             params={'item_barcode': barcode},
-                             headers=self._get_headers(data_format='xml'))
+            r = self._api_call('get',
+                               self.api_base_url_items,
+                               params={'item_barcode': barcode},
+                               headers=self._get_headers())
             if r.ok is True:
                 logging.info(f"{repr(self)}: item data fetched with barcode '{barcode}'")
                 return XmlData(r.content)
@@ -132,9 +133,10 @@ class Item(Record):
 
         # No barcode provided
         else:
-            r = requests.get(f'{self.api_base_url_bibs}/{self.bib.mms_id}/holdings/{self.holding.holding_id}'
-                             f'/items/{self.item_id}',
-                             headers=self._get_headers(data_format='xml'))
+            r = self._api_call('get',
+                               f'{self.api_base_url_bibs}/{self.bib.mms_id}/holdings/{self.holding.holding_id}'
+                               f'/items/{self.item_id}',
+                               headers=self._get_headers())
 
             if r.ok is True:
 
@@ -143,24 +145,17 @@ class Item(Record):
             else:
                 self._handle_error(r, 'unable to fetch item data')
 
-    def _create_item(self, data: etree.Element, mms_id: Optional[str] = None, holding_id: Optional[str] = None):
+    def _create_item(self, data: etree.Element):
         """
         Create an item to the holding with the provided data.
         :param data: item data
-        :param mms_id: related bib record mms_id
-        :param holding_id: related holding record ID
 
         :return: Item
         """
-        if mms_id is None:
-            mms_id = self.bib.mms_id
-
-        if holding_id is None:
-            holding_id = self.holding.holding_id
-
-        r = requests.post(f'{self.api_base_url_bibs}/{mms_id}/holdings/{holding_id}/items',
-                          headers=self._get_headers(data_format='xml'),
-                          data=etree.tostring(data))
+        r = self._api_call('post',
+                           f'{self.api_base_url_bibs}/{self.bib.mms_id}/holdings/{self.holding.holding_id}/items',
+                           headers=self._get_headers(),
+                           data=etree.tostring(data))
 
         if r.ok is True:
             self.data = XmlData(r.content)
@@ -304,10 +299,11 @@ class Item(Record):
 
         :return: Item
         """
-        r = requests.put(f'{self.api_base_url_bibs}/{self.bib.mms_id}/holdings/{self.holding.holding_id}/'
-                         f'items/{self.item_id}',
-                         data=bytes(self),
-                         headers=self._get_headers(data_format='xml'))
+        r = self._api_call('put',
+                           f'{self.api_base_url_bibs}/{self.bib.mms_id}/holdings/{self.holding.holding_id}/'
+                           f'items/{self.item_id}',
+                           data=bytes(self),
+                           headers=self._get_headers())
 
         if r.ok is True:
             self.data = XmlData(r.content)
@@ -324,9 +320,10 @@ class Item(Record):
 
         :return: None
         """
-        r = requests.delete(f'{self.api_base_url_bibs}/{self.bib.mms_id}/holdings/{self.holding.holding_id}'
-                            f'/items/{self.item_id}',
-                            headers=self._get_headers(data_format='xml'))
+        r = self._api_call('delete',
+                           f'{self.api_base_url_bibs}/{self.bib.mms_id}/holdings/{self.holding.holding_id}'
+                           f'/items/{self.item_id}',
+                           headers=self._get_headers())
         if r.ok is True:
             logging.info(f'{repr(self)} deleted')
         else:
